
Avoid the use of default and predictable acounts.
-------

**Description:**

Whenever default or predictable acounts are available on an application/server this could 
lead to an attacker compromising these services.


**Solution:**

Make sure al default and predictable acounts are disabled or deleted from the services. 
Also implement a strong password policy.

	